@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Apache::Voodoo::Install::Updater
+Apache::Voodoo::Install::Updater - Update xml processor
 
 =head1 SYNOPSIS
 
@@ -13,6 +13,8 @@ use directly by end users.
 =cut ###########################################################################
 package Apache::Voodoo::Install::Updater;
 
+$VERSION = '1.21';
+
 use strict;
 use warnings;
 
